﻿#include <QApplication>
#include <QPushButton>
#include <QDoubleSpinBox>
#include <QBoxLayout>
#include <QMessageBox>
#include <QDialogButtonBox>

#include "notifymanager.h"

const QStringList g_notifies = {
    "我从来不相信什么懒洋洋的自由，我向往的自由是通过勤奋和努力实现的更广阔的人生，那样的自由才是珍贵的、有价值的。",
    "我相信一万小时定律，我从来不相信天上掉馅饼的灵感和坐等的成就。",
    "做一个自由又自律的人，靠势必实现的决心认真地活着。",
    "你的脸上云淡风轻，谁也不知道你的牙咬得有多紧。",
    "你走路带着风，谁也不知道你膝盖上仍有曾摔伤的淤青。",
    "你笑得没心没肺，没人知道你哭起来只能无声落泪。",
    "要让人觉得毫不费力，只能背后极其努力。",
    "我们没有改变不了的未来，只有不想改变的过去。",
    "如果逃避眼前的现实，越是逃，就越是会陷入痛苦的境地。",
    "要有面对问题的勇气，渡过这个困境的话，应该就能一点点地解决问题。感激遇到的所有人吧。",
    "虽然晚了点，依靠自己的力量前进吧。为了开始新的人生。"
};

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);

    QWidget w;
    QVBoxLayout *layout = new QVBoxLayout(&w);
    QPushButton * button1 = new QPushButton("提示1", &w);
    QPushButton * button100 = new QPushButton("提示100", &w);
    QPushButton * button10000 = new QPushButton("提示10000", &w);
    QPushButton * buttonblack = new QPushButton("提示(黑色样式)", &w);
    QPushButton * button60s = new QPushButton("提示(60秒)", &w);
    QPushButton * buttonTimer = new QPushButton("匀速添加提示", &w);
    QDoubleSpinBox * spinBoxTime = new QDoubleSpinBox(&w);
    layout->addWidget(button1);
    layout->addWidget(button100);
    layout->addWidget(button10000);
    layout->addWidget(buttonblack);
    layout->addWidget(button60s);
    layout->addWidget(buttonTimer);
    layout->addWidget(spinBoxTime);

    buttonTimer->setCheckable(true);
    spinBoxTime->setSuffix("秒");
    spinBoxTime->setSingleStep(0.1);
    w.resize(300,80);
    w.setWindowTitle("浮动提示框");

    NotifyManager *manager = new NotifyManager(&w);
    manager->setMaxCount(5);
    manager->setDisplayTime(5000);
    manager->setNotifyWndSize(300, 80);
    manager->setStyleSheet("#notify-background {"
                           "background: black;"
                           "}"
                           "#notify-title{"
                           "font: bold 14px 黑体;"
                           "color: #eeeeee;"
                           "}"
                           "#notify-body{"
                           "font: 12px 黑体;"
                           "color: #dddddd;"
                           "}"
                           "#notify-close-btn{ "
                           "border: 0;"
                           "color: #999999;"
                           "}"
                           "#notify-close-btn:hover{ "
                           "background: #444444;"
                           "}", "black");

    int count = 1;
    qsrand(QDateTime::currentMSecsSinceEpoch());
    QObject::connect(button1, &QPushButton::clicked, manager, [manager, &count]{
        QString text = g_notifies[qrand()%g_notifies.size()];
        manager->notify(QString("新消息%1").arg(count++), text);
    });
    QObject::connect(button100, &QPushButton::clicked, manager, [button1]{
        for (int i=0; i<100; i++) button1->click();
    });
    QObject::connect(button10000, &QPushButton::clicked, manager, [button1]{
        for (int i=0; i<10000; i++) button1->click();
    });
    QObject::connect(buttonblack, &QPushButton::clicked, manager, [manager, &count]{
        QVariantMap data;
        data["theme"] = "black";
        QString text = g_notifies[qrand()%g_notifies.size()];
        manager->notify(QString("黑色样式消息%1").arg(count++), text, data);
    });
    QObject::connect(button60s, &QPushButton::clicked, manager, [manager, &count]{
        QVariantMap data;
        data["displayTime"] = 60*1000;
        QString text = g_notifies[qrand()%g_notifies.size()];
        manager->notify(QString("60秒消息%1").arg(count++), text, data);
    });

    QTimer timer;
    QObject::connect(&timer, &QTimer::timeout, button1, &QPushButton::click);
    QObject::connect(spinBoxTime, QOverload<double>::of(&QDoubleSpinBox::valueChanged), &timer, [&timer](double value){
        timer.setInterval(value*1000);
    });
    QObject::connect(buttonTimer, &QPushButton::clicked, &timer, [&timer](bool checked){
        if (checked) timer.start();
        else timer.stop();
    });

    QObject::connect(manager, &NotifyManager::notifyDetial, [](const QVariantMap &data){
        QMessageBox msgbox(QMessageBox::Information, "新消息", data.value("title").toString());
        msgbox.setDetailedText(data.value("body").toString());
        msgbox.findChild<QDialogButtonBox*>()->setMinimumWidth(500);
        msgbox.exec();
    });

    spinBoxTime->setValue(0.5);
    w.show();
    return app.exec();
}
